--[[

InteriorLocations is a module containing information about all the "interiors"
I have found in the game.  Some of this data is very old, "but it still works!"
The module is just a large table and a few basic accessors.

If you're not already familiar with the landscape and interiors systems, check
the accompanying interiors.txt for a very short explanation.

For each interior in the table, the module provides: its name as seen on the
minimap; the DataID for its map for use with SetBackground etc.; the width and
height of the map image; and region, lx, and ly coordinates as shown by /loc.

To use the module, simply import it then use one of these functions:


  InteriorLocations.iter()
  Iterator to support generic for loops. For example:

  for my_interior in InteriorLocations.iter() do
    local test_name = string.lower(my_interior.name)
    if test_name:find("barad") ~= nil then
      Turbine.Shell.WriteLine("Tower found: "..my_interior.name)
    end
  end


  InteriorLocations.find_did(did)
  Find a location's indices in the table by its image DataID.  Indices, plural,
  because multiple locations may share an image.  This happens with the old
  and new versions of the Fornost towers, for example.  Use this function
  if you have the DataID of an interior, but don't know which interior.  For
  example:

  local did = 0x410E6A9F -- We found this picture, what interior is it?
  local indices = InteriorLocations.find_did(did)
  if indices == nil then
    Turbine.Shell.WriteLine("No interior found with map image "..tostring(did))
  else
    for _, index in ipairs(indices) do
      local data = InteriorLocations.get(index)
      Turbine.Shell.WriteLine("The image is used for "..data.name)
    end
  end


  InteriorLocations.find_name(name)
  Find a location's indices in the table by its name.  Case-sensitive.
  Complements find_did.


  InteriorLocations.get(i)
  Get a location by its index in the table or nil if the index is not found.
  Use this rather than accessing the table directly, because the table is
  stored without keys. The returned table will have these members:
    name      -- the name of the interior as seen on the minimap
    did       -- the DataID of the interior's map image for SetBackground etc.
    w, h      -- the dimensions of the map image
    r, lx, ly -- the coordinates of the interior as reported by /loc

  The width of the map image can be 800, 1600, or 2400.  The height can be 600,
  1200, or 1800.    I guess but am yet to prove that these correspond to 1x1,
  2x2, or 3x3 landblocks, or equivalently 8x8, 16x16, or 24x24 land coordinates,
  that is, lx, ly.

  The coordinates can be used together with a /loc macro to find out where the
  player is.  Note that most interiors are larger than a single point in the
  lx ly land coordinates.  As far as I know, interiors will not be larger than
  3 landblocks either way, or an extent of 24 land coordinates.  lx and ly give
  the southwest corner.  I have not yet found any false results from using this:

    -- True if the point lx, ly lies inside InteriorLocations entry e
    function is_point_in_interior(lx, ly, e)
      return lx >= e.lx and lx < e.lx + 24 and ly >= e.ly and ly < e.ly + 24
    end

]]

InteriorLocations = {
  -- Entries sorted by region then name then DataID.
  -- I have disambiguated many of the duplicate names, for example the multiple
  -- interiors all named "Barad Guldur". I did not bother with the numerous
  -- "Standard House", or with generic quest locations like "Prison". I may add
  -- Others are of course welcome to.

  -- Region 1: Eriador
  { "Archet Jail", 0x41005C30, 800, 600, 1, 976, 992 },
  { "Artie Root's House", 0x41123C9C, 800, 600, 1, 128, 1880 },
  { "Auction Hall", 0x41118B3E, 800, 600, 1, 1976, 1152 }, -- Galtrev
  { "Bag End", 0x41007DB2, 800, 600, 1, 2000, 920 },
  { "Bar-e-Therchir", 0x410D74B6, 800, 600, 1, 1992, 1064 },
  { "Barad Dhorn", 0x4101D9A3, 800, 600, 1, 1192, 944 },
  { "Barad D\195\186rgul", 0x410DB394, 800, 600, 1, 1984, 1944 },
  { "Barad Eithel", 0x41007DB4, 800, 600, 1, 912, 1208 }, -- old
  { "Barad Eithel", 0x41007DB4, 800, 600, 1, 24, 1936 }, -- scaled
  { "Barad G\195\186laran", 0x4101EFB7, 1600, 1200, 1, 1976, 1952 },
  { "Barad Harn", 0x41007DB5, 800, 600, 1, 936, 1192 }, -- old
  { "Barad Harn", 0x41007DB5, 800, 600, 1, 24, 1920 }, -- scaled
  { "Barad Narthan", 0x41007DB6, 800, 600, 1, 920, 1208 }, -- old
  { "Barad Narthan", 0x41007DB6, 800, 600, 1, 24, 1904 }, -- scaled
  { "Barad Thars\195\173r", 0x41110A3D, 800, 600, 1, 856, 1080 },
  { "Barad Thars\195\173r Storeroom", 0x41110A3F, 800, 600, 1, 856, 1088 },
  { "Barad Tironn", 0x41020483, 1600, 1200, 1, 2000, 568 },
  { "Barnavon Mine", 0x4111831B, 800, 600, 1, 1320, 392 },
  { "Barrow Downs", 0x41102342, 800, 600, 1, 912, 920 },
  { "Beneath the Forsaken Inn", 0x411138EB, 1600, 1200, 1, 1976, 1216 },
  { "Benton Oakes's Library", 0x41005D77, 800, 600, 1, 2024, 752 },
  { "Bilbo's Room\nDecember 24th", 0x410E573C, 800, 600, 1, 1976, 1912 },
  { "Black Dens", 0x41105824, 800, 600, 1, 1984, 1520 },
  { "Blackwold Camp", 0x41005BD3, 1600, 1200, 1, 1968, 1288 },
  { "Blackwold Camp", 0x4110938A, 1600, 1200, 1, 784, 904 },
  { "Blackwold Jail", 0x41109390, 800, 600, 1, 1968, 1288 },
  { "Blackwold Jail", 0x4110938D, 800, 600, 1, 784, 904 },
  { "Blue Stone Garrison", 0x410D3FDD, 1600, 1200, 1, 2000, 504 },
  { "Boffin Manor", 0x4115E07F, 800, 600, 1, 1976, 1104 },
  { "Boffin Manor", 0x4115E080, 800, 600, 1, 1976, 1120 },
  { "Bornabar", 0x410D8161, 800, 600, 1, 2000, 432 },
  { "Bree-town Auction Hall", 0x41007DBF, 800, 600, 1, 2000, 760 },
  { "Bree-town Hall", 0x4101E2A7, 800, 600, 1, 2008, 760 },
  { "Bree-town Hunting Lodge", 0x410D3FDF, 800, 600, 1, 2000, 448 },
  { "Bree-town Jail", 0x4101E11F, 800, 600, 1, 2008, 744 },
  { "Bree-town Vault", 0x4101DF97, 800, 600, 1, 2000, 696 },
  { "Bregmor's Den", 0x410E6A9F, 1600, 1200, 1, 2032, 568 },
  { "Brigand Cave", 0x41005E1F, 800, 600, 1, 2000, 1224 },
  { "Brigand Cave", 0x41005C2F, 800, 600, 1, 912, 1024 },
  { "Brockenborings Watch Office", 0x41005E08, 800, 600, 1, 2000, 1168 },
  { "B\195\161vor Wyrm-brand's Tomb", 0x41108D74, 1600, 1200, 1, 8, 1904 }, -- scaled
  { "B\195\161vor Wyrm-brand's Tomb", 0x4101D9A0, 1600, 1200, 1, 1480, 1056 }, -- old
  { "B\195\187rzum Pushdug", 0x41005CCD, 1600, 1200, 1, 2008, 1928 },
  { "Carn D\195\187m Sewers", 0x41007DBD, 800, 600, 1, 1128, 1368 }, -- Pale Folk
  { "Carn D\195\187m Sewers", 0x4100A684, 1600, 1200, 1, 1136, 1384 }, -- Helchgam
  { "Cartwell's House", 0x4100A646, 800, 600, 1, 2000, 704 },
  { "Castle of the Witch-king", 0x41005D2A, 1600, 1200, 1, 1112, 1384 }, -- dungeon
  { "Castle of the Witch-king", 0x410D43BB, 800, 1800, 1, 1976, 1936 }, -- epic
  { "Combe Crafting Hall", 0x4101FE09, 800, 600, 1, 2008, 728 },
  { "Cook's Guild Hall", 0x410F2E04, 800, 600, 1, 1984, 1712 },
  { "Craft-hall of Esteld\195\173n", 0x410DCF3D, 800, 600, 1, 1976, 1904 },
  { "Craftguilder's Hall", 0x4111A09B, 800, 600, 1, 1976, 1136 },
  { "Crafting Hall", 0x4110E1E1, 800, 600, 1, 1984, 1760 }, -- Thorin's Gate
  { "Crafting Hall", 0x41118B52, 800, 600, 1, 1976, 1184 }, -- Galtrev
  { "Crug Cadelhin", 0x41105821, 800, 600, 1, 912, 16 },
  { "Crug Fernvael", 0x41105825, 800, 600, 1, 1984, 1504 },
  { "Delossad", 0x410D73F3, 1600, 1200, 1, 2000, 1064 },
  { "Delotham", 0x41105816, 1600, 1200, 1, 1984, 1456 },
  { "Deluxe House", 0x410D98AD, 800, 600, 1, 1904, 1848 },
  { "Deluxe House", 0x410D98B0, 800, 600, 1, 1904, 1752 },
  { "Deluxe House", 0x410D98B1, 800, 600, 1, 1880, 1752 },
  { "Deluxe House", 0x410D98B2, 800, 600, 1, 1912, 1784 },
  { "Deluxe House", 0x410D98B5, 800, 600, 1, 1912, 1816 },
  { "Deluxe House", 0x410D98B6, 800, 600, 1, 1880, 1784 },
  { "Deluxe House", 0x410D98B7, 800, 600, 1, 1912, 1848 },
  { "Deluxe House", 0x410D98BA, 800, 600, 1, 1880, 1816 },
  { "Deluxe House", 0x410D98BD, 800, 600, 1, 1880, 1848 },
  { "Deluxe House", 0x410D98C0, 800, 600, 1, 1888, 1752 },
  { "Deluxe House", 0x410D98C3, 800, 600, 1, 1888, 1784 },
  { "Deluxe House", 0x410D98C6, 800, 600, 1, 1888, 1816 },
  { "Deluxe House", 0x410D98C9, 800, 600, 1, 1888, 1848 },
  { "Deluxe House", 0x410D98CC, 800, 600, 1, 1896, 1752 },
  { "Deluxe House", 0x410D98CF, 800, 600, 1, 1896, 1784 },
  { "Deluxe House", 0x410D98D2, 800, 600, 1, 1896, 1816 },
  { "Deluxe House", 0x410D98D5, 800, 600, 1, 1896, 1848 },
  { "Deluxe House", 0x410D98DA, 800, 600, 1, 1904, 1784 },
  { "Deluxe House", 0x410D98DD, 800, 600, 1, 1904, 1816 },
  { "Deluxe House", 0x410E611B, 800, 600, 1, 1912, 1752 },
  { "Den of the Northern Army", 0x410D980D, 800, 600, 1, 2016, 600 },
  { "Dolendath", 0x410E611A, 800, 600, 1, 1984, 1904 },
  { "Dor G\195\187l", 0x410DAC90, 800, 600, 1, 2008, 1888 },
  { "Draigoch's Lair", 0x41117318, 800, 600, 1, 1176, 64 },
  { "Draugroth", 0x410D74BE, 800, 600, 1, 1992, 1072 },
  { "Elendil's Tomb", 0x4101FCD2, 1600, 1200, 1, 2000, 632 },
  { "Ellie Cutleaf's House", 0x41005E1E, 800, 600, 1, 2000, 1216 },
  { "Ellie Cutleaf's House", 0x41005E1E, 800, 600, 1, 2000, 1024 },
  { "Elrond's Library", 0x41005CF7, 800, 600, 1, 2016, 1960 },
  { "Esilia's House", 0x41005DBE, 800, 600, 1, 2000, 1128 },
  { "Esteld\195\173n Library\nDecember 8th", 0x4100A645, 800, 600, 1, 1056, 1144 },
  { "Etten Caves", 0x41007DB0, 800, 600, 1, 2000, 1144 },
  { "Experimentation Pit", 0x4111C52E, 800, 600, 1, 1976, 1760 },
  { "Filgog\195\162n", 0x410EA78D, 1600, 1200, 1, 1392, 696 },
  { "Foreman's Quarters", 0x410DD1B1, 800, 600, 1, 2000, 904 },
  { "Forsaken Smial", 0x41020102, 800, 600, 1, 2000, 1008 },
  { "Gabilazan Vault", 0x41007DB3, 800, 600, 1, 1984, 1968 },
  { "Gador G\195\186laran", 0x410EA772, 1600, 1200, 1, 1984, 1632 }, -- caverns
  { "Gador G\195\186laran", 0x410EA771, 800, 600, 1, 1984, 1616 }, -- tower
  { "Gath Forthn\195\173r", 0x41005BF3, 800, 600, 1, 2008, 1768 },
  { "Gerebert's House", 0x41005E07, 800, 600, 1, 2000, 1160 },
  { "Glinghant", 0x410200CA, 1600, 1200, 1, 8, 1984 },
  { "Goblin-town", 0x410D9813, 800, 600, 1, 2016, 592 }, -- Slave-pens
  { "Goblin-town Depths", 0x410D980F, 800, 600, 1, 2016, 584 }, -- Thundergrot
  { "Goblin-town Tunnels", 0x410D9811, 1600, 1200, 1, 2016, 560 }, -- North
  { "Goblin-town Tunnels", 0x410D9812, 1600, 1200, 1, 2016, 568 }, -- Central
  { "Goblin-town Tunnels", 0x410D9810, 1600, 1200, 1, 2016, 576 }, -- South
  { "Goetham", 0x4110A04B, 800, 600, 1, 8, 1696 },
  { "Gollum's Cave", 0x410D9814, 800, 600, 1, 2016, 608 },
  { "Gorthban", 0x410D815E, 800, 600, 1, 1992, 1184 },
  { "Gorthban Approach", 0x410D815F, 1600, 1200, 1, 2000, 368 },
  { "Great Lodge of S\195\187ri-kyl\195\164", 0x410E47B2, 800, 600, 1, 1976, 1888 },
  { "Great Smials", 0x41005E09, 800, 600, 1, 2000, 1176 },
  { "Greenfields Warren", 0x41005BCA, 1600, 1200, 1, 2000, 1360 },
  { "Grobo Dogwort's House", 0x41123C96, 800, 600, 1, 2008, 2000 },
  { "Grobo Dogwort's Shed", 0x41123C97, 800, 600, 1, 2008, 2032 },
  { "Guard-house of Isengard", 0x41118317, 800, 600, 1, 1584, 1816 },
  { "Guest Rooms\nDecember 24th", 0x410E573D, 800, 600, 1, 1984, 1912 },
  { "Gwantham", 0x4110A04E, 800, 600, 1, 8, 1712 },
  { "Gwindethrond", 0x4101FD4F, 800, 600, 1, 2000, 648 },
  { "Halbarad's Study\nDecember 8th", 0x41005CC7, 800, 600, 1, 1992, 1208 },
  { "Halla-kolo", 0x410DCC7B, 1600, 1200, 1, 2000, 1568 },
  { "Halmur Stoneshaper's Tomb", 0x41005D78, 800, 600, 1, 2000, 1048 },
  { "Haudh Arantar", 0x41110D2E, 1600, 1200, 1, 800, 1064 },
  { "Haudh Eldacar", 0x41110D2C, 1600, 1200, 1, 792, 1072 },
  { "Haudh E\195\164rendur", 0x41110D29, 800, 600, 1, 800, 1080 },
  { "Haudh Iarchith", 0x4110A04C, 1600, 1200, 1, 8, 1728 },
  { "Haudh Methernil", 0x4110A051, 800, 600, 1, 8, 1808 },
  { "Haudh Nogbenn", 0x4110A052, 800, 600, 1, 8, 1680 },
  { "Haudh Taenthond", 0x4110A04F, 1600, 1200, 1, 8, 1760 },
  { "Haudh Valandur", 0x41110D27, 800, 600, 1, 800, 1072 },
  { "Hautham", 0x4110A053, 800, 600, 1, 8, 1744 },
  { "Helegrod Treasury", 0x4101880B, 1600, 1200, 1, 2008, 1904 },
  { "Hoarwell Water Cavern", 0x411138EE, 1600, 1200, 1, 1976, 1216 },
  { "Holt Adderson's Grotto", 0x41005D2E, 800, 600, 1, 2000, 856 },
  { "Homestead Provisions", 0x410D7CD9, 800, 600, 1, 992, 880 }, -- Bree
  { "Homestead Provisions", 0x410D7CC6, 800, 600, 1, 728, 872 }, -- MD
  { "Hunting Lodge", 0x41005CC4, 800, 600, 1, 992, 992 },
  { "Icereave Mines", 0x410DD1B2, 800, 600, 1, 2000, 904 }, -- upper
  { "Icereave Mines", 0x410DD1B1, 800, 600, 1, 2000, 904 }, -- lower
  { "Infiltrators' Headquarters", 0x41123C94, 800, 600, 1, 2000, 1192 },
  { "Iorvinas", 0x410FC489, 1600, 1200, 1, 2000, 200 },
  { "Isferon's Study", 0x41005D28, 800, 600, 1, 2000, 784 },
  { "Jeweller's Guild-hall", 0x410F2E02, 800, 600, 1, 1984, 1680 },
  { "Kinship House", 0x410D98AC, 800, 600, 1, 1904, 1840 },
  { "Kinship House", 0x410D98AE, 800, 600, 1, 1880, 1744 },
  { "Kinship House", 0x410D98B4, 800, 600, 1, 1880, 1776 },
  { "Kinship House", 0x410D98B9, 800, 600, 1, 1880, 1808 },
  { "Kinship House", 0x410D98BC, 800, 600, 1, 1880, 1840 },
  { "Kinship House", 0x410D98BF, 800, 600, 1, 1888, 1744 },
  { "Kinship House", 0x410D98C2, 800, 600, 1, 1888, 1776 },
  { "Kinship House", 0x410D98C5, 800, 600, 1, 1888, 1808 },
  { "Kinship House", 0x410D98C8, 800, 600, 1, 1888, 1840 },
  { "Kinship House", 0x410D98CB, 800, 600, 1, 1896, 1744 },
  { "Kinship House", 0x410D98CE, 800, 600, 1, 1896, 1776 },
  { "Kinship House", 0x410D98D1, 800, 600, 1, 1896, 1808 },
  { "Kinship House", 0x410D98D4, 800, 600, 1, 1896, 1840 },
  { "Kinship House", 0x410D98D7, 800, 600, 1, 1904, 1744 },
  { "Kinship House", 0x410D98D9, 800, 600, 1, 1904, 1776 },
  { "Kinship House", 0x410D98DC, 800, 600, 1, 1904, 1808 },
  { "Kr\195\186sl\195\171 Lannan", 0x4101880C, 1600, 1200, 1, 2008, 1896 },
  { "Laenan", 0x41103F10, 1600, 1200, 1, 2000, 72 },
  { "Laerdan's Chamber", 0x410DACEF, 800, 600, 1, 1976, 1920 },
  { "Lalia's Market", 0x411331AF, 800, 600, 1, 2016, 744 },
  { "Lhaid Ogo", 0x411112A0, 1600, 1200, 1, 2016, 288 },
  { "Lhan Colvarn", 0x41118311, 800, 600, 1, 1984, 1328 },
  { "Lhe Colvarn", 0x41105826, 800, 600, 1, 1984, 1488 },
  { "Lighthouse", 0x41110A40, 800, 600, 1, 840, 1096 },
  { "Lorn Pass", 0x41005D29, 800, 600, 1, 2000, 808 },
  { "Lost Temple", 0x41110BE7, 800, 600, 1, 1984, 1376 },
  { "Lower Noruidor", 0x410D8160, 800, 600, 1, 2000, 400 },
  { "Mess Hall", 0x41108CE6, 800, 600, 1, 1992, 1224 },
  { "Metalworker's Guild-hall", 0x410F2E05, 800, 600, 1, 1984, 1728 },
  { "Minas Agar", 0x410DB492, 800, 600, 1, 1992, 1936 },
  { "Minas Angos", 0x410DB491, 800, 600, 1, 1992, 1928 },
  { "Minas Caul", 0x410DB494, 800, 600, 1, 1992, 1952 },
  { "Minas Elend\195\186r", 0x41105815, 1600, 1200, 1, 1984, 1472 },
  { "Minas Erain", 0x41007DB7, 800, 600, 1, 936, 1208 }, -- old
  { "Minas Erain", 0x41007DB7, 800, 600, 1, 24, 1888 }, -- scaled
  { "Minas Maur", 0x410DB493, 800, 600, 1, 1992, 1944 },
  { "Mirkstone Tunnels", 0x41005C0D, 800, 600, 1, 1976, 2008 },
  { "Morfil", 0x41005CCE, 1600, 1200, 1, 2008, 1936 },
  { "Mustering Cave", 0x41005CD0, 1600, 1200, 1, 2008, 2008 },
  { "Nellie Boskins' House", 0x41005CD1, 800, 600, 1, 1992, 1216 },
  { "Norbar", 0x410D815C, 800, 600, 1, 2000, 336 }, -- Shadow-eater and Stone-biter
  { "Norbar", 0x410DA4E5, 1600, 1200, 1, 2000, 320 }, -- Thrang
  { "Norbar", 0x411044DA, 800, 600, 1, 8, 2000 }, -- skirmish
  { "Norbar", 0x411BB235, 800, 1800, 1, 2016, 336 }, -- Shadow-eater room, allegiance
  { "Norbar", 0x411BB234, 2400, 3000, 1, 2016, 320 }, -- Thrang's room, allegiance
  { "Norbar Approach", 0x410D815D, 800, 600, 1, 2000, 416 },
  { "Nurath", 0x41005D2D, 800, 600, 1, 1328, 920 },
  { "N\195\164ky-kolo", 0x410E0CD1, 800, 600, 1, 2000, 1856 },
  { "Ologfil", 0x41005CCA, 1600, 1200, 1, 2008, 1920 },
  { "Orthanc", 0x41118313, 800, 600, 1, 1584, 1840 },
  { "Orthanc Throne-room", 0x4111C52F, 800, 600, 1, 1976, 1744 },
  { "Ost Dunhoth", 0x4110C4D3, 1600, 1200, 1, 24, 1984 }, -- Lobby and Wound
  { "Ost Dunhoth", 0x4110C4D5, 1600, 1200, 1, 24, 2000 }, -- Disease and Poison
  { "Ost Dunhoth", 0x4110C4D9, 800, 600, 1, 24, 1968 }, -- Ivar
  { "Ost Dunhoth", 0x4110C4DC, 800, 600, 1, 24, 1952 }, -- Gortheron
  { "Ost Elendil", 0x410D4368, 800, 600, 1, 2000, 488 }, -- old
  { "Ost Elendil", 0x410D4368, 800, 600, 1, 8, 1968 }, -- scaled
  { "Outbuildings of Isengard", 0x4111E43D, 800, 600, 1, 1816, 952 },
  { "Peikko Den", 0x410E37D0, 800, 600, 1, 2000, 896 },
  { "Pits of Isengard", 0x4111D00D, 1600, 1200, 1, 1976, 1808 },
  { "Plas-maru", 0x41116361, 800, 600, 1, 1328, 480 },
  { "Prison-caves", 0x41118308, 1600, 1200, 1, 2016, 304 },
  { "Prototype", 0x410D985B, 800, 600, 1, 1888, 1728 },
  { "Reniolind's Hideout", 0x41005CD3, 800, 600, 1, 1992, 1336 },
  { "Rimp\195\186rod", 0x41007DB1, 1600, 1200, 1, 2008, 1944 },
  { "Rockbelly Pit", 0x41007DC5, 800, 600, 1, 1976, 2000 },
  { "Saeradan's Cabin", 0x4100E7B0, 800, 600, 1, 936, 984 },
  { "Sammath Baul", 0x410DB84C, 800, 600, 1, 1976, 1944 },
  { "Sarn\195\186r Great Hall", 0x41091B65, 1600, 1200, 1, 2000, 1888 },
  { "Sarn\195\186r Keep", 0x41091B64, 800, 600, 1, 1992, 1896 },
  { "Sarn\195\186r Caverns", 0x41091B63, 1600, 1200, 1, 1992, 1888 },
  { "Saruman's Laboratory", 0x4111BA64, 800, 600, 1, 1976, 1792 },
  { "Scary Quarry", 0x41005DBD, 800, 600, 1, 2000, 1104 },
  { "Scholar's Enclave", 0x41005BD2, 800, 600, 1, 2008, 784 },
  { "Scholar's Guild-hall", 0x410F2E01, 800, 600, 1, 1984, 1664 },
  { "Scholar's Stair Archives", 0x4101E11E, 800, 600, 1, 2008, 736 },
  { "Sig Mandrake's Shop", 0x41123C95, 800, 600, 1, 2000, 1296 },
  { "Silver Deep", 0x41005C1F, 800, 600, 1, 1976, 2016 },
  { "Silver Deep Guard House", 0x41005D30, 800, 600, 1, 2000, 992 },
  { "Skorgr\195\173m's Tomb", 0x41005C2D, 1600, 1200, 1, 1984, 2016 },
  { "Skud Carchar", 0x41104769, 800, 600, 1, 1984, 1552 },
  { "Skunkwood's House", 0x4100F457, 800, 600, 1, 1024, 952 },
  { "Sprigley's Cellar", 0x41007DBE, 800, 600, 1, 2000, 1184 },
  { "Staddle Arms", 0x41007DC0, 800, 600, 1, 968, 928 },
  { "Standard House", 0x410D98AB, 800, 600, 1, 1904, 1824 },
  { "Standard House", 0x410D98AF, 800, 600, 1, 1904, 1856 },
  { "Standard House", 0x410D98B3, 800, 600, 1, 1880, 1760 },
  { "Standard House", 0x410D98B8, 800, 600, 1, 1880, 1792 },
  { "Standard House", 0x410D98BB, 800, 600, 1, 1880, 1824 },
  { "Standard House", 0x410D98BE, 800, 600, 1, 1880, 1856 },
  { "Standard House", 0x410D98C1, 800, 600, 1, 1888, 1760 },
  { "Standard House", 0x410D98C4, 800, 600, 1, 1888, 1792 },
  { "Standard House", 0x410D98C7, 800, 600, 1, 1888, 1824 },
  { "Standard House", 0x410D98CA, 800, 600, 1, 1888, 1856 },
  { "Standard House", 0x410D98CD, 800, 600, 1, 1896, 1760 },
  { "Standard House", 0x410D98D0, 800, 600, 1, 1896, 1792 },
  { "Standard House", 0x410D98D3, 800, 600, 1, 1896, 1824 },
  { "Standard House", 0x410D98D6, 800, 600, 1, 1896, 1856 },
  { "Standard House", 0x410D98D8, 800, 600, 1, 1904, 1760 },
  { "Standard House", 0x410D98DB, 800, 600, 1, 1904, 1792 },
  { "Steamworks of Orthanc", 0x4111BDF5, 800, 600, 1, 1976, 1776 },
  { "S\195\162ri-surma", 0x411122A8, 800, 600, 1, 1984, 1360 }, -- Coldbear
  { "S\195\162ri-surma", 0x411122AA, 800, 600, 1, 1984, 1344 }, -- Osan
  { "Tailor's Guild-hall", 0x410F2E03, 800, 600, 1, 1984, 1696 },
  { "Tawarond ", 0x410F02E3, 800, 600, 1, 2016, 528 },
  { "Tham Giliath", 0x41005CC5, 800, 600, 1, 1992, 1200 },
  { "Tham Send, the Hall of Rest", 0x411BC621, 800, 600, 1, 1976, 1024 },
  { "Tham \195\186md\195\186r", 0x41103F0D, 1600, 1200, 1, 1984, 1584 },
  { "The Ale Association Ale-hall", 0x41104CE1, 800, 600, 1, 2000, 216 },
  { "The Arming-Cave", 0x41005C2C, 800, 600, 1, 1984, 2008 },
  { "The Barrow of Ringdor", 0x4110A055, 800, 600, 1, 8, 1792 },
  { "The Barrow of Taradan", 0x4110A050, 800, 600, 1, 8, 1776 },
  { "The Bird and Baby Inn", 0x41005BC9, 800, 600, 1, 712, 904 },
  { "The Brackwater", 0x410EA78F, 800, 600, 1, 1416, 744 },
  { "The Brenin's Hall", 0x41109FF0, 800, 600, 1, 1984, 1392 },
  { "The Cat Lady's House", 0x41007DB9, 800, 600, 1, 2000, 712 },
  { "The Comb and Wattle Basement", 0x41005E06, 800, 600, 1, 2024, 2016 },
  { "The Comb and Wattle Inn", 0x41005CD2, 800, 600, 1, 2008, 2016 },
  { "The Deep Path", 0x4111830F, 800, 600, 1, 1984, 1248 },
  { "The Delving of Fr\195\179r", 0x410D81C3, 1600, 1200, 1, 2000, 584 },
  { "The Festival Arena", 0x4110041D, 800, 600, 1, 2000, 184 },
  { "The Festival Garden", 0x411045F6, 1600, 1200, 1, 2000, 168 },
  { "The Floating Log Inn", 0x41005C1E, 800, 600, 1, 784, 920 },
  { "The Flooded Ward", 0x41103F0F, 1600, 1200, 1, 1984, 1600 },
  { "The Forsaken Inn", 0x41005CC6, 800, 600, 1, 1976, 1200 }, -- normal
  { "The Forsaken Inn", 0x411138C8, 800, 600, 1, 1976, 1216 },
  { "The Forsaken Road", 0x41104484, 800, 600, 1, 1976, 1872 },
  { "The Foundry", 0x4111E2DD, 1600, 1200, 1, 1840, 1120 },
  { "The Frostbluff Theatre", 0x4110DF5F, 800, 600, 1, 2000, 304 },
  { "The Golden Perch", 0x41005C2E, 800, 600, 1, 824, 920 },
  { "The Great Barrow", 0x41005DBF, 1600, 1200, 1, 2000, 1152 }, -- old
  { "The Great Barrow", 0x41108EB2, 800, 600, 1, 8, 1856 }, -- The Maze
  { "The Great Barrow", 0x41005DBF, 1600, 1200, 1, 8, 1872 }, -- Sambrog
  { "The Great Barrow", 0x41108EB6, 800, 600, 1, 8, 1840 }, -- Thadur
  { "The Great Barrow", 0x41108EBA, 800, 600, 1, 8, 1824 }, -- Othrongroth
  { "The Great Goblin's Den", 0x41132DB1, 2400, 1800, 1, 2016, 632 }, -- Seat main
  { "The Great Goblin's Den", 0x41132DB2, 1600, 1200, 1, 2016, 632 }, -- Seat below
  { "The Great Goblin's Den", 0x410D980E, 800, 600, 1, 2016, 616 }, -- old
  { "The Green Dragon", 0x41005BF4, 800, 600, 1, 768, 920 },
  { "The Greenhouse", 0x41108F2B, 800, 600, 1, 1984, 1992 },
  { "The Hall of Fire", 0x41005D7C, 800, 600, 1, 2024, 1960 }, -- normal
  { "The Hall of Fire", 0x41005D7C, 800, 600, 1, 1984, 48 },
  { "The Hall of Making", 0x4110A06C, 800, 600, 1, 1984, 1536 },
  { "The Halls of Night", 0x411130DB, 1600, 1200, 1, 2000, 232 },
  { "The Haunted Burrow", 0x41109384, 800, 600, 1, 1984, 1408 },
  { "The Haunted Burrow", 0x41109382, 800, 600, 1, 1984, 1408 },
  { "The Haunted Burrow", 0x41109383, 800, 600, 1, 1984, 1408 },
  { "The House of Tom Bombadil", 0x41005D7E, 800, 600, 1, 2000, 1088 },
  { "The Ivy Bush", 0x41005BD1, 800, 600, 1, 752, 928 },
  { "The Jailor's Quarters", 0x41105823, 800, 600, 1, 976, 16 },
  { "The Keg-race of Thorin's Hall", 0x41123E03, 800, 600, 1, 2000, 136 },
  { "The Last Homely House", 0x41005CCF, 1600, 1200, 1, 2008, 1960 },
  { "The Library at Tham M\195\173rdain", 0x41108D70, 1600, 1200, 1, 2016, 1824 }, -- old
  { "The Library at Tham M\195\173rdain", 0x41108D72, 800, 600, 1, 8, 1936 }, -- scaled
  { "The Long Maw", 0x41118310, 800, 600, 1, 1984, 1264 },
  { "The Lore-tower", 0x4101D9A1, 800, 600, 1, 1168, 928 },
  { "The Lowbanks' Estate", 0x4101E11D, 800, 600, 1, 2008, 752 },
  { "The Mad Badger Inn", 0x41005E1D, 800, 600, 1, 2000, 1208 },
  { "The Mathom House", 0x410D3FDE, 800, 600, 1, 2000, 520 },
  { "The Michel Delving Training Hall", 0x4101E193, 800, 600, 1, 2000, 672 },
  { "The Michel Delving Vendor Hall", 0x4101E1A7, 800, 600, 1, 2000, 680 },
  { "The Old Father", 0x41105B30, 800, 600, 1, 1984, 1424 },
  { "The Plough and Stars", 0x41005C2B, 800, 600, 1, 784, 960 },
  { "The Prancing Pony", 0x41005E20, 800, 600, 1, 2000, 1256 },
  { "The Refuge of Edhelion", 0x4110595B, 800, 600, 1, 456, 1104 },
  { "The Savage Dens", 0x41118B6B, 800, 600, 1, 1984, 1280 },
  { "The Scholar's Hall", 0x411AB8F1, 800, 600, 1, 1976, 1048 },
  { "The School at Tham M\195\173rdain", 0x410E8A03, 800, 600, 1, 2016, 1816 }, -- old
  { "The School at Tham M\195\173rdain", 0x41108D6F, 800, 600, 1, 8, 1920 }, -- scaled
  { "The Shire Auction Hall", 0x41007DB8, 800, 600, 1, 2000, 752 },
  { "The Sprawling Dark", 0x4111830D, 800, 600, 1, 1984, 1296 },
  { "The Taste of Hobbiton", 0x41104484, 800, 600, 1, 2000, 152 },
  { "Thingroth", 0x41005D2C, 1600, 1200, 1, 1280, 944 },
  { "Thorgest's Haven", 0x410D9A55, 800, 600, 1, 1536, 992 },
  { "Thorin's Hall", 0x41005D2F, 1600, 1200, 1, 1944, 2000 }, -- main
  { "Thorin's Hall", 0x410D4163, 1600, 1200, 1, 1944, 2000 }, -- lower
  { "Three-farrow Crafting Hall", 0x41005D13, 800, 600, 1, 2000, 728 },
  { "Tinnudir Keep", 0x4102042E, 800, 600, 1, 2000, 536 },
  { "Tomb of Maenadar", 0x4110A04A, 1600, 1200, 1, 8, 1664 }, -- public
  { "Tomb of Maenadar", 0x410E6989, 800, 600, 1, 2032, 576 }, -- epic
  { "Tookland Post Office", 0x41005D7D, 800, 600, 1, 2000, 1072 },
  { "Torech Mordeloth", 0x4101D9A4, 1600, 1200, 1, 1472, 1056 }, -- old
  { "Torech Mordeloth", 0x41108D76, 1600, 1200, 1, 8, 1888 }, -- scaled
  { "Torogrod", 0x41005D2B, 1600, 1200, 1, 1264, 944 },
  { "Training Hall", 0x41118B50, 800, 600, 1, 1976, 1168 },
  { "Training Hall", 0x41005CD4, 800, 600, 1, 2000, 720 },
  { "Training Hall", 0x41132F9D, 800, 600, 1, 2024, 736 },
  { "Tunnel to Asht-Sh\195\162pol", 0x4101D9A2, 800, 600, 1, 1160, 1328 },
  { "Upper Noruidor", 0x410D8163, 1600, 1200, 1, 2000, 472 },
  { "Valandil's Tomb", 0x410201AD, 1600, 1200, 1, 2000, 600 }, -- old
  { "Valandil's Tomb", 0x410201AD, 1600, 1200, 1, 8, 1952 }, -- scaled
  { "Vault of Celebr\195\173an's Legacy", 0x41007DBC, 800, 600, 1, 2000, 888 },
  { "Weapons and Armour Shop", 0x41007DBA, 800, 600, 1, 2000, 744 },
  { "Weapons and Armour Shop", 0x41007DBB, 800, 600, 1, 2000, 736 },
  { "Weaponsmith's Guild-hall", 0x410F2E06, 800, 600, 1, 1984, 1744 },
  { "White Hand Encampment", 0x4111908A, 800, 600, 1, 1984, 1312 },
  { "Whitethorn's Taxidermy", 0x410E4314, 800, 600, 1, 2008, 704 },
  { "Woodworker's Guild-hall", 0x410F2E00, 800, 600, 1, 1984, 1648 },
  { "Zudrugund", 0x41105B31, 800, 600, 1, 1984, 1440 },

  -- Region 2: "Rhovanion" (a bad name for it)
  { "Abandoned Farmhouse", 0x4112A48B, 800, 600, 2, 1968, 1360 },
  { "Abandoned Farmhouse", 0x4112A480, 800, 600, 2, 1968, 1376 },
  { "Agelric's House", 0x41130FE1, 800, 600, 2, 24, 840 },
  { "Agistath", 0x410FB9D8, 1600, 1200, 2, 2016, 296 },
  { "Aldburg Armoury", 0x4114248E, 800, 600, 2, 1952, 1008 },
  { "Aldburg Auction Hall", 0x41134C56, 800, 600, 2, 1968, 1088 },
  { "Aldburg Barber", 0x41142455, 800, 600, 2, 1920, 128 },
  { "Aldburg Mead Hall", 0x41142454, 800, 600, 2, 1896, 96 },
  { "Aldburg Skirmish Hall", 0x41134AFA, 800, 600, 2, 1968, 1104 },
  { "Aldburg Tavern", 0x41142452, 800, 600, 2, 1896, 192 },
  { "Aldburg Tomb", 0x41142C74, 800, 600, 2, 1880, 776 },
  { "Aldburg Vault", 0x41142466, 800, 600, 2, 1896, 56 },
  { "Apothecary's Shop", 0x4112DEC4, 800, 600, 2, 1968, 1232 },
  { "Armoury", 0x41131D05, 800, 600, 2, 1928, 880 },
  { "Armoury", 0x41140AA1, 800, 600, 2, 640, 616 },
  { "Auction Hall", 0x4112B4BD, 800, 600, 2, 24, 920 },
  { "Auction Hall", 0x41123E32, 800, 600, 2, 2000, 1392 }, -- Stangard
  { "Auction Hall", 0x410FB6E7, 800, 600, 2, 1984, 232 },
  { "Auctioneer's Bunker", 0x410F70B2, 800, 600, 2, 2032, 1360 },
  { "Azanaruk\195\162r", 0x410F1E75, 1600, 1200, 2, 2032, 1616 }, -- Fall of Moria
  { "Azanaruk\195\162r", 0x410EA775, 800, 600, 2, 2032, 1696 }, -- 2.6.8 upper
  { "Azanaruk\195\162r", 0x410EA777, 1600, 1200, 2, 2032, 1696 }, -- 2.6.8 lower, 2.8.6
  { "Barad Guldur", 0x41101F57, 1600, 1200, 2, 2016, 1968 }, -- Twins
  { "Barad Guldur", 0x41101F55, 1600, 1200, 2, 2016, 1968 }, -- Durchest
  { "Barad Guldur", 0x41101F59, 1600, 1200, 2, 2016, 1968 }, -- Lieutenant
  { "Barad Guldur", 0x41101D7E, 800, 600, 2, 2016, 1936 }, -- Battle in the Tower
  { "Barracks", 0x4112B4B7, 800, 600, 2, 24, 936 },
  { "Beaconwatch Mead Hall", 0x41142462, 800, 600, 2, 1896, 128 },
  { "Beaconwatch Tavern", 0x41142458, 800, 600, 2, 1936, 128 },
  { "Bernwyn's House", 0x41130FE3, 800, 600, 2, 24, 856 },
  { "Blacksmith", 0x41131D07, 800, 600, 2, 1944, 880 },
  { "Blacksmith of Floodwend", 0x41130D3F, 800, 600, 2, 1928, 832 },
  { "Brockbridge Mead Hall", 0x4114246F, 800, 600, 2, 1288, 48 },
  { "Bult-k\195\162r", 0x410F7FA2, 800, 600, 2, 2016, 640 },
  { "Burg-sh\195\161pol", 0x4114244D, 1600, 1200, 2, 1896, 160 },
  { "Buzun-gh\195\162r", 0x410F4C06, 800, 600, 2, 2032, 1504 },
  { "Byre Tor Home", 0x41139046, 800, 600, 2, 1288, 32 },
  { "Byre Tor Home", 0x41139047, 800, 600, 2, 1336, 32 },
  { "Byre Tor Home", 0x41139048, 800, 600, 2, 1304, 32 },
  { "Byre Tor Home", 0x41139049, 800, 600, 2, 1320, 32 },
  { "Byre Tor Home", 0x4113904A, 800, 600, 2, 1352, 32 },
  { "Byrgenstow", 0x4112881F, 1600, 1200, 2, 2016, 1456 },
  { "Byrnstan's House", 0x4112361E, 800, 600, 2, 2000, 1216 },
  { "Chamber of Dancing Shadows", 0x410EA76D, 800, 600, 2, 2016, 1776 },
  { "Chamber of Wheels", 0x410EA76E, 1600, 1200, 2, 2032, 1520 },
  { "Cliving Jail", 0x4112B97F, 800, 600, 2, 1968, 1296 },
  { "Cook's Guild", 0x41142451, 800, 600, 2, 1968, 1024 },
  { "Court of Celeborn", 0x411A75AE, 1600, 1200, 2, 2000, 1760 },
  { "Craft Hall of Snowbourn", 0x41130E0D, 800, 600, 2, 24, 904 },
  { "Crafting Antechamber", 0x41137FA7, 800, 600, 2, 1952, 1024 },
  { "Crafting Bunker", 0x410F70B4, 800, 600, 2, 2032, 1392 },
  { "Crafting Hall", 0x410FB6E9, 800, 600, 2, 2000, 232 },
  { "Crafting Hall", 0x4110166D, 800, 600, 2, 2032, 1312 },
  { "Dark Delvings", 0x410EAE29, 1600, 1200, 2, 2032, 1968 },
  { "Dorr-sh\195\162troful", 0x41142453, 1600, 1200, 2, 1896, 176 },
  { "Dunfast Barn", 0x41139045, 800, 600, 2, 1928, 56 },
  { "Dunfast Home", 0x41139032, 800, 600, 2, 1944, 56 },
  { "Dunfast Home", 0x41139034, 800, 600, 2, 1952, 56 },
  { "Dunfast Home", 0x41139037, 800, 600, 2, 1960, 72 },
  { "Dunfast Home", 0x41139038, 800, 600, 2, 1936, 72 },
  { "Dunfast Home", 0x4113903B, 800, 600, 2, 1976, 72 },
  { "Dunfast Home", 0x41139040, 800, 600, 2, 1992, 72 },
  { "Dunfast Home", 0x41139043, 800, 600, 2, 2008, 72 },
  { "Dungeons of Dol Guldur", 0x410FF31A, 1600, 1200, 2, 2016, 1984 }, -- 3-player (now 6)
  { "Dungeons of Dol Guldur", 0x41101F8E, 1600, 1200, 2, 2016, 1920 }, -- epic
  { "Dunstan's House", 0x41123DFF, 800, 600, 2, 2000, 1200 },
  { "Dwergfant", 0x4112A9AF, 800, 600, 2, 2016, 1856 },
  { "Dwolung Hole", 0x4112FB1A, 800, 600, 2, 1912, 192 },
  { "D\195\162r Narbugud", 0x410FA16A, 800, 600, 2, 2000, 1984 }, -- Rung and Blagh
  { "D\195\162r Narbugud", 0x410FA16A, 800, 600, 2, 2032, 1984 },
  { "D\195\162r Narbugud", 0x410FA16B, 800, 600, 2, 2000, 1968 }, -- Zholuga
  { "D\195\162r Narbugud", 0x410FF064, 800, 600, 2, 2000, 1952 }, -- Flagit and Istum
  { "D\195\162r Narbugud", 0x410FA16C, 800, 600, 2, 2000, 1936 }, -- BO and Mistress
  { "Eastmund's Lair", 0x4112FB16, 800, 600, 2, 2008, 192 },
  { "Eaworth Infirmary", 0x41129E75, 800, 600, 2, 1984, 1392 },
  { "Eaworth Jail", 0x41129E77, 800, 600, 2, 1984, 1424 },
  { "Eaworth Provisions", 0x41129E76, 800, 600, 2, 2016, 1232 },
  { "Edsig's Home", 0x41139058, 800, 600, 2, 2000, 144 },
  { "Eldora's Home", 0x4112CA22, 800, 600, 2, 1968, 1168 },
  { "Elfwyn's Shop", 0x4112B6BA, 800, 600, 2, 1968, 1312 },
  { "Elgyth's House", 0x411406CB, 800, 600, 2, 648, 608 },
  { "Entwade Mead Hall", 0x41139FF6, 800, 600, 2, 1968, 1568 },
  { "Farm Homestead", 0x4112FB0D, 800, 600, 2, 1968, 176 },
  { "Fastred's House", 0x4112B4B9, 800, 600, 2, 8, 984 },
  { "Fenmarch Home", 0x41142464, 800, 600, 2, 1952, 128 },
  { "Fenmarch Mead Hall", 0x4114245F, 800, 600, 2, 1896, 112 },
  { "Fenmarch Supplier", 0x4114245D, 800, 600, 2, 1968, 128 },
  { "Fil Gashan", 0x410EAA40, 1600, 1200, 2, 2032, 1952 },
  { "Filikul", 0x410F710A, 800, 600, 2, 2000, 1000 },
  { "Fisherman's Shop", 0x4112FB05, 800, 600, 2, 2016, 176 },
  { "Folcbur's Homestead", 0x41141E2E, 800, 600, 2, 1952, 928 },
  { "Food Storehouse", 0x411406C9, 800, 600, 2, 648, 616 },
  { "Forlaw Barber", 0x41139060, 800, 600, 2, 2000, 160 },
  { "Forlaw Barracks", 0x4113905B, 800, 600, 2, 1936, 144 },
  { "Forlaw Basement", 0x4113905A, 800, 600, 2, 1968, 160 },
  { "Forlaw Crafting Hall", 0x4113905E, 800, 600, 2, 1952, 160 },
  { "Forlaw Feasting Hall", 0x4113904E, 800, 600, 2, 1984, 160 },
  { "Forlaw Infirmary", 0x41139053, 800, 600, 2, 1984, 144 },
  { "Forlaw Legendary", 0x4113904D, 800, 600, 2, 1968, 144 },
  { "Forlaw Skirmish Hall", 0x4113904C, 800, 600, 2, 1920, 160 },
  { "Frithild's House", 0x41141FBF, 800, 600, 2, 1944, 776 },
  { "Fulz-zahar", 0x410F7FA0, 800, 600, 2, 2016, 664 },
  { "Gadorgar", 0x41101F35, 800, 600, 2, 2032, 1344 },
  { "Gamilnaf\195\187k", 0x410EA76A, 800, 600, 2, 2032, 1728 },
  { "Garsfeld Legendary Services", 0x41130FE4, 800, 600, 2, 8, 840 },
  { "Gate-house of the Lonely Mountain", 0x41133FD6, 800, 600, 2, 1968, 1136 },
  { "Gath Ulunn", 0x410FC421, 800, 600, 2, 2016, 312 },
  { "Gemyndsted", 0x4114D49E, 800, 600, 2, 1984, 1104 },
  { "General Store", 0x41142475, 800, 600, 2, 1256, 48 },
  { "General Store", 0x41142477, 800, 600, 2, 1272, 48 },
  { "Gh\195\162r-bayur", 0x410EA76B, 800, 600, 2, 2016, 1744 },
  { "Gh\195\162r-khafush", 0x410EA77D, 1600, 1200, 2, 2032, 1792 },
  { "Great Hall of the Hornburg", 0x41140AA0, 800, 600, 2, 576, 608 }, -- before the battle
  { "Great Hall of the Hornburg", 0x411424A9, 800, 600, 2, 1000, 1936 }, -- after midnight
  { "Great Hall of the Hornburg", 0x411424AB, 800, 1800, 2, 1288, 1936 },
  { "Great Hall of the Hornburg", 0x411424AC, 800, 600, 2, 1144, 1936 }, -- before dawn
  { "Great Hall of the Hornburg", 0x4114AD57, 1600, 1200, 2, 1952, 1152 }, -- sunrise
  { "Grimslade Mead Hall", 0x411406CA, 800, 600, 2, 640, 608 },
  { "Gr\195\173ma's Quarters", 0x411409FD, 800, 600, 2, 1952, 992 },
  { "Guard House", 0x4115BEBC, 1600, 1200, 2, 1968, 1056 },
  { "Guard-house of Isengard", 0x4114B862, 800, 600, 2, 1944, 728 },
  { "Guardhouse", 0x411406C8, 800, 600, 2, 640, 600 },
  { "Gurz-sh\195\162pol", 0x411406C2, 800, 600, 2, 1952, 1072 },
  { "Gwathrendath", 0x410EA77B, 800, 600, 2, 2032, 1760 },
  { "G\195\161rferth's Home", 0x41139055, 800, 600, 2, 1920, 144 },
  { "G\195\161rsig's Home", 0x41139057, 800, 600, 2, 2016, 144 },
  { "G\195\173sling's House", 0x41130FE5, 800, 600, 2, 8, 824 },
  { "Halls of Crafting", 0x410FB02F, 800, 600, 2, 2000, 2032 }, -- first
  { "Halls of Crafting", 0x410FB02F, 800, 600, 2, 2032, 1904 },
  { "Halls of Crafting", 0x410FF066, 800, 600, 2, 2000, 2016 }, -- second
  { "Halls of Crafting", 0x410FF065, 800, 600, 2, 2000, 2000 }, -- third
  { "Harwick Auction Hall", 0x4112FAFB, 800, 600, 2, 2000, 248 },
  { "Harwick Bank", 0x4112FAF8, 800, 600, 2, 2016, 248 },
  { "Harwick Barber Shop", 0x4112FB04, 800, 600, 2, 2016, 160 },
  { "Harwick Barracks", 0x4112FB0A, 800, 600, 2, 1944, 192 },
  { "Harwick Crafting Hall", 0x4112FAF9, 800, 600, 2, 1984, 248 },
  { "Harwick General Store", 0x4112FAFC, 800, 600, 2, 1952, 176 },
  { "Harwick Legendary Store", 0x4112FB00, 800, 600, 2, 1952, 192 },
  { "Harwick Prison", 0x4112FB08, 800, 600, 2, 1920, 176 },
  { "Harwick Quartermaster Shop", 0x4112FB02, 800, 600, 2, 1984, 176 },
  { "Harwick Tavern", 0x4112FB06, 800, 600, 2, 1936, 176 },
  { "Haycliff", 0x4112B2E8, 1600, 1200, 2, 2016, 1792 },
  { "Haycliff", 0x4112B2E6, 1600, 1200, 2, 2016, 1792 },
  { "Hermit Home", 0x4112FB11, 800, 600, 2, 1992, 176 },
  { "Herubrand's Hideout", 0x41142474, 800, 600, 2, 1304, 48 },
  { "Hidden Burrow", 0x411244B7, 800, 600, 2, 2016, 1296 },
  { "Hidden Cave", 0x41139067, 800, 600, 2, 1336, 16 },
  { "House", 0x41130D19, 800, 600, 2, 1880, 896 },
  { "House", 0x41131D02, 800, 600, 2, 1896, 896 },
  { "House", 0x41131D04, 800, 600, 2, 1912, 896 },
  { "House", 0x41131D06, 800, 600, 2, 1928, 896 },
  { "House", 0x41131D08, 800, 600, 2, 1944, 896 },
  { "House", 0x41131D09, 800, 600, 2, 1960, 896 },
  { "Hubryt's House", 0x4113039B, 800, 600, 2, 24, 888 },
  { "Ingmar's House", 0x41129E74, 800, 600, 2, 1984, 1120 },
  { "Inhild's Home", 0x4112C9FD, 800, 600, 2, 1968, 1184 },
  { "Iothete's Home", 0x41139021, 800, 600, 2, 1936, 160 },
  { "Iserngraf", 0x41129D3D, 1600, 1200, 2, 2000, 1856 },
  { "Jeweller's Guild", 0x4114245A, 800, 600, 2, 1968, 1008 },
  { "Kheled-menem", 0x410EA792, 800, 600, 2, 2032, 1552 },
  { "Khibir-zamu", 0x410EA765, 800, 600, 2, 2032, 1712 },
  { "Khibir-zarur", 0x410EA779, 800, 600, 2, 2016, 1712 },
  { "Langhold General Store", 0x4112FAFF, 800, 600, 2, 1952, 208 },
  { "Langhold Home", 0x4112FB10, 800, 600, 2, 1984, 192 },
  { "Legendary Item Store", 0x41123E33, 800, 600, 2, 2000, 1264 },
  { "Lornsettle", 0x4113904F, 800, 600, 2, 1976, 56 },
  { "Lost Archive", 0x411BA17C, 1600, 1200, 2, 1944, 1168 },
  { "L\195\161thbear Den", 0x4112AA16, 800, 600, 2, 1968, 1488 },
  { "Mamalsul", 0x410EA791, 1600, 1200, 2, 2032, 1536 },
  { "Marton Basement", 0x411406C4, 800, 600, 2, 600, 672 },
  { "Marton Basement", 0x411406C5, 800, 600, 2, 600, 680 },
  { "Marton Basement", 0x411406C7, 800, 600, 2, 616, 680 },
  { "Marton Basement", 0x411406CC, 800, 600, 2, 616, 672 },
  { "Marton Mead Hall", 0x411406C6, 800, 600, 2, 608, 680 },
  { "Mead Hall", 0x41130D15, 800, 600, 2, 1848, 896 },
  { "Mead Hall", 0x41130D18, 1600, 1200, 2, 1864, 896 },
  { "Mead Hall of Cliving", 0x4112E991, 800, 600, 2, 1968, 1280 },
  { "Mead Hall of Eaworth", 0x41129E72, 800, 600, 2, 2000, 1456 },
  { "Mead Hall of Elthengels", 0x4112DD4C, 800, 600, 2, 1968, 1264 },
  { "Mead Hall of Faldham", 0x4112E992, 800, 600, 2, 1968, 1248 },
  { "Mead Hall of Floodwend", 0x4112FAF7, 800, 600, 2, 1960, 832 },
  { "Mead Hall of Garsfeld", 0x41130BFB, 800, 600, 2, 8, 856 },
  { "Mead Hall of Harwick", 0x4112672A, 800, 600, 2, 2008, 56 },
  { "Mead Hall of Langhold", 0x4112FAF2, 800, 600, 2, 1992, 56 },
  { "Mead Hall of Oserley", 0x41141FC5, 800, 600, 2, 1896, 776 },
  { "Mead Hall of Snowbourn", 0x4112B4BA, 800, 600, 2, 8, 1000 },
  { "Mead Hall of Stoke", 0x41141FC3, 800, 600, 2, 1960, 776 },
  { "Mead Hall of Thornhope", 0x4112D5BF, 800, 600, 2, 792, 824 },
  { "Mead Hall of Walstow", 0x41130BFA, 800, 600, 2, 8, 888 },
  { "Meduseld", 0x4112F98F, 800, 600, 2, 736, 616 },
  { "Mekeb-faham", 0x410F7FAA, 1600, 1200, 2, 2016, 656 },
  { "Mekeb-farak", 0x410F7FAD, 800, 600, 2, 2016, 648 },
  { "Menem-nar", 0x410EA768, 800, 600, 2, 2032, 1632 },
  { "Metalsmith's Guild", 0x41142456, 800, 600, 2, 1968, 992 },
  { "Mezel-katub", 0x410EA763, 800, 600, 2, 2032, 1568 },
  { "Mezel-saluch", 0x410EA767, 800, 600, 2, 2032, 1600 },
  { "Middlemead Mead Hall", 0x4114109C, 800, 600, 2, 1968, 1584 },
  { "Minas Gil", 0x4110206B, 800, 600, 2, 976, 1088 },
  { "Minas Rant", 0x4112A706, 800, 600, 2, 1968, 1472 },
  { "Mor-hai Cave", 0x41123BE7, 800, 600, 2, 2016, 1328 },
  { "Mukhful Thurkh", 0x410FB1E7, 800, 600, 2, 2032, 1424 },
  { "M\195\161gla's Home", 0x4114109E, 800, 600, 2, 1952, 1040 },
  { "Nona's Cave", 0x41139066, 800, 600, 2, 1352, 16 },
  { "Nothgar", 0x411013C1, 800, 600, 2, 1000, 1112 },
  { "Nothgar Cellar", 0x41101B72, 800, 600, 2, 2032, 1328 },
  { "Nud-heden", 0x410EA76C, 800, 600, 2, 2016, 1760 },
  { "Ordlac's House", 0x41141FC6, 800, 600, 2, 1912, 776 },
  { "Ordwacer's Home", 0x4112BEAE, 800, 600, 2, 1968, 1200 },
  { "Ost Celebrant Ruins", 0x41123499, 800, 600, 2, 896, 928 },
  { "Ost Magol", 0x4112ACB9, 1600, 1200, 2, 2016, 1824 },
  { "Parph\195\161d", 0x411295B6, 800, 600, 2, 2000, 1872 },
  { "Peculiar Home", 0x41142648, 800, 600, 2, 1920, 112 },
  { "Pits of Isengard", 0x4114B863, 800, 600, 2, 1960, 728 },
  { "Prison", 0x41134C56, 800, 600, 2, 1968, 1072 },
  { "Provisioner's Home", 0x41123E00, 800, 600, 2, 2000, 1232 },
  { "Randgar's Home", 0x4112CD78, 800, 600, 2, 1968, 1152 },
  { "Ransacked Home", 0x4112FB0B, 800, 600, 2, 2016, 208 },
  { "Ransacked Home", 0x4112FB0C, 800, 600, 2, 2000, 208 },
  { "Ransacked Home", 0x4112FB12, 800, 600, 2, 1984, 208 },
  { "Roots of Fangorn", 0x4111F090, 800, 600, 2, 2016, 1888 },
  { "R\195\162d Cened", 0x4110242B, 1600, 1200, 2, 2032, 288 },
  { "R\195\162d Iorist", 0x41102EBD, 1600, 1200, 2, 2032, 296 },
  { "Sabert's House", 0x41123E38, 800, 600, 2, 2000, 1184 },
  { "Sahard's Barn", 0x4112B6AE, 800, 600, 2, 1968, 1328 },
  { "Sahard's Farm", 0x4112B6AF, 800, 600, 2, 1968, 1344 },
  { "Sammath G\195\187l", 0x41101EBA, 1600, 1200, 2, 2016, 1952 },
  { "Scholar's Guild", 0x41142465, 800, 600, 2, 1968, 976 },
  { "Scylfig Mead Hall", 0x41137E3A, 800, 600, 2, 1968, 1536 },
  { "Sejer-thar\195\162kh", 0x410F7FA6, 1600, 1200, 2, 2016, 632 },
  { "Signoth's Estate", 0x41141D6D, 800, 600, 2, 1952, 1056 },
  { "Skirmish Hall", 0x41123DEC, 800, 600, 2, 2000, 1408 },
  { "Sk\195\187mfil", 0x410EAE21, 1600, 1200, 2, 2032, 2032 },
  { "Snowbourn House", 0x4112B4B4, 800, 600, 2, 8, 952 },
  { "Snowbourn House", 0x4112B4B6, 800, 600, 2, 24, 952 },
  { "Snowbourn House", 0x4112B4BB, 800, 600, 2, 8, 968 },
  { "Snowbourn House", 0x4112B4BE, 800, 600, 2, 24, 968 },
  { "Snowbourn Jail", 0x4112B4BF, 800, 600, 2, 8, 904 },
  { "Snowbourn Tavern", 0x4112B4C3, 800, 600, 2, 8, 936 },
  { "Snowbourn Vault", 0x4112B4B5, 800, 600, 2, 8, 920 },
  { "Soothsayer Cave", 0x4114247D, 800, 600, 2, 1320, 48 },
  { "Springview Estate", 0x41129EEA, 800, 600, 2, 1968, 1408 },
  { "Springview Estate", 0x4112A476, 800, 600, 2, 1968, 1392 },
  { "Stable", 0x41131D03, 800, 600, 2, 1912, 880 },
  { "Stangard Jail", 0x4111F368, 800, 600, 2, 2000, 1424 },
  { "Stangard Kennel", 0x41123E31, 800, 600, 2, 2000, 1312 },
  { "Stangard Mead Hall", 0x4111F1A4, 800, 600, 2, 2000, 1440 },
  { "Stangard Tavern", 0x41123E36, 800, 600, 2, 2000, 1360 },
  { "Stangard Vault", 0x41123DE9, 800, 600, 2, 2000, 1376 },
  { "Stangraf", 0x4114D49D, 800, 600, 2, 1952, 960 },
  { "Stanric Household", 0x41123493, 800, 600, 2, 2000, 1328 },
  { "Steaping Cave", 0x41139063, 800, 600, 2, 1320, 16 },
  { "Stoke Inn", 0x41141FCA, 800, 600, 2, 1928, 776 },
  { "Study", 0x41131D01, 800, 600, 2, 1896, 880 },
  { "Supplier's Home", 0x4112387F, 800, 600, 2, 2000, 1248 },
  { "Sword-hall of Dol Guldur", 0x41101F5A, 1600, 1200, 2, 2016, 2000 },
  { "Tailor's Guild", 0x4114245B, 800, 600, 2, 1968, 960 },
  { "Tatwine's House", 0x41123DFE, 800, 600, 2, 2000, 1136 },
  { "Tavern", 0x411358FC, 800, 600, 2, 1968, 1040 },
  { "Tavern of Floodwend", 0x41130D3D, 800, 600, 2, 1944, 832 },
  { "The Ancient Tomb", 0x4112DE9C, 1600, 1200, 2, 1968, 1520 },
  { "The Bleak Cellar", 0x4110163A, 800, 600, 2, 904, 1104 },
  { "The Chamber of Command", 0x410F5DEB, 800, 600, 2, 2032, 1872 },
  { "The Chamber of Leadership", 0x410EA77E, 800, 600, 2, 2032, 1808 },
  { "The Creeping Wood", 0x4112AB42, 1600, 1200, 2, 24, 1064 },
  { "The Deep Way", 0x410EA782, 1600, 1200, 2, 2032, 1856 }, -- public
  { "The Deep-way", 0x4110B659, 1600, 1200, 2, 8, 1984 }, -- skirmish
  { "The Drowned Treasury", 0x410EA77F, 1600, 1200, 2, 2032, 1824 },
  { "The Forges of Khazad-d\195\187m", 0x410EE41C, 1600, 1200, 2, 2032, 2016 },
  { "The Forgotten Treasury", 0x410EAE25, 1600, 1200, 2, 2032, 2000 },
  { "The Ghost-forge", 0x410EA7FE, 800, 600, 2, 2016, 1728 },
  { "The Hall of Lights", 0x410FB986, 1600, 1200, 2, 2016, 288 },
  { "The Haunted Inn", 0x41101639, 800, 600, 2, 904, 1104 },
  { "The Heart of Fire", 0x410EA781, 1600, 1200, 2, 2032, 1840 },
  { "The Library of Steel", 0x410EA762, 800, 600, 2, 2016, 1632 },
  { "The Mirror-halls of Lumul-nar", 0x410FA92E, 1600, 1200, 2, 2016, 2016 },
  { "The Mirror-halls of Lumul-nar", 0x410FA92E, 1600, 1200, 2, 2000, 1920 },
  { "The Mithril-slaves", 0x410EA769, 800, 600, 2, 2016, 1696 },
  { "The Morroval-outcasts", 0x410EA764, 800, 600, 2, 2016, 1664 },
  { "The Mud", 0x41142471, 800, 600, 2, 1240, 48 },
  { "The Peaceful Path", 0x410EA77C, 800, 600, 2, 2032, 1776 },
  { "The Reeve's Kitchen", 0x4112BEAD, 800, 600, 2, 1968, 1216 },
  { "The Spider-nest", 0x410EA761, 800, 600, 2, 2016, 1616 },
  { "The Stone-hole", 0x4111F091, 800, 600, 2, 2016, 1424 },
  { "The Throne of Durin", 0x410FB7D2, 1600, 1200, 2, 2016, 1808 },
  { "The Training Hall", 0x410EA766, 800, 600, 2, 2016, 1680 },
  { "The Under-wall", 0x4112D29E, 1600, 1200, 2, 952, 688 },
  { "The Water Wheels: Nal\195\162-d\195\187m", 0x410FA8B7, 1600, 1200, 2, 2000, 1904 },
  { "The Water Wheels: Nal\195\162-d\195\187m", 0x410FA8B7, 1600, 1200, 2, 2016, 2032 },
  { "The Way of Smiths", 0x410EA780, 1600, 1200, 2, 2032, 1840 }, -- public
  { "The Way of Smiths", 0x410EA780, 1600, 1200, 2, 1792, 1872 }, -- old book 5
  { "The Way of Smiths", 0x4110C500, 1600, 1200, 2, 8, 1968 }, -- skirmish
  { "Thrymm's House", 0x41139054, 800, 600, 2, 1896, 144 },
  { "Thurimen", 0x410FBAE6, 1600, 1200, 2, 2016, 304 },
  { "Tumun-gh\195\162r", 0x410F7FA5, 800, 600, 2, 2016, 672 },
  { "Tunzul-menem", 0x410EA774, 800, 600, 2, 2032, 1680 },
  { "Umukh-kanon", 0x410EA760, 800, 600, 2, 2032, 1584 },
  { "Underharrow Home", 0x411408BB, 800, 600, 2, 1952, 1104 },
  { "Underharrow Home", 0x411408FF, 800, 600, 2, 1952, 1120 },
  { "Underharrow Mead Hall", 0x411408BA, 800, 600, 2, 1952, 1088 },
  { "Uthrad's House", 0x41123E39, 800, 600, 2, 2000, 1120 },
  { "Vault", 0x410FB6E8, 800, 600, 2, 2016, 232 },
  { "Vault-keeper's Bunker", 0x410F70B3, 800, 600, 2, 2032, 1376 },
  { "Venom-bite Cave", 0x41123BE8, 800, 600, 2, 2016, 1312 },
  { "Wada's House", 0x411238EB, 800, 600, 2, 2000, 1280 },
  { "Walstow Legendary Services", 0x41130FE2, 800, 600, 2, 24, 872 },
  { "Warg-pens of Dol Guldur", 0x41101EB9, 1600, 1200, 2, 1024, 1080 },
  { "Weaponsmith's Guild", 0x4114245C, 800, 600, 2, 1968, 944 },
  { "Winsig's House", 0x41130FDF, 800, 600, 2, 8, 872 },
  { "Woodhurst Mead Hall", 0x41142472, 800, 600, 2, 1336, 48 },
  { "Woodhurst Tavern", 0x41142476, 800, 600, 2, 1352, 48 },
  { "Woodworker's Guild", 0x41142460, 800, 600, 2, 1968, 928 },
  { "Writhendowns Tomb", 0x41136CF8, 800, 600, 2, 1968, 1552 },
  { "Wyrmdelf", 0x4112884F, 1600, 1200, 2, 2016, 1472 }, -- lower
  { "Wyrmdelf", 0x4112884E, 1600, 1200, 2, 2016, 1472 }, -- upper
  { "W\195\179dscrafen", 0x4112FB17, 800, 600, 2, 1968, 192 },
  { "Zurr-thar\195\187kh", 0x410EA778, 800, 600, 2, 2016, 1648 },
  { "Zurr-thurkh", 0x410FBA55, 800, 600, 2, 2032, 1440 },
  { "Z\195\186rsnaga's Hideout", 0x4112B099, 800, 600, 2, 1968, 1504 },
  { "Eomer's Home", 0x4114091B, 800, 600, 2, 1952, 1136 },
  { "Eowyn's Quarters", 0x41141D28, 800, 600, 2, 1952, 944 },

  -- Region 3: Gondor
  { "Abandoned Vault", 0x4115ED41, 800, 600, 3, 2000, 1952 },
  { "Apothecary", 0x41155121, 800, 600, 3, 2016, 2000 },
  { "Armoury of Dol Amroth", 0x41155294, 800, 600, 3, 2032, 2032 },
  { "Barracks", 0x41155156, 800, 600, 3, 2000, 2016 },
  { "Cand\195\186r's Hideout", 0x41155159, 800, 600, 3, 2000, 2000 },
  { "Caverns of Emyn Ernil", 0x41154E0F, 1600, 1200, 3, 2032, 1704 },
  { "Caves of the Avorrim", 0x411552AE, 800, 600, 3, 784, 496 },
  { "Chamber of the Anor-stone", 0x41167868, 800, 600, 3, 2016, 1688 }, -- before
  { "Chamber of the Anor-stone", 0x41167867, 800, 600, 3, 2016, 1672 }, -- besieged
  { "Cisterns of Minas Tirith", 0x41167589, 1600, 1200, 3, 2016, 1752 },
  { "City Stables of Minas Tirith", 0x41167863, 1600, 1200, 3, 2016, 1608 },
  { "Clothiers' Fellow-hall", 0x41167875, 800, 600, 3, 2016, 1872 },
  { "Corsair Cave", 0x41159212, 1600, 1200, 3, 2032, 1688 },
  { "Dead Cave", 0x41159217, 1600, 1200, 3, 2032, 1656 },
  { "Dead Cave", 0x41159217, 1600, 1200, 3, 1984, 2032 },
  { "Deluxe Premium House", 0x411A4B94, 800, 600, 3, 1880, 1824 },
  { "Deluxe Premium House", 0x411A4B95, 800, 600, 3, 1880, 1808 },
  { "Dol Amroth Warehouse", 0x4115529A, 800, 600, 3, 2032, 2000 },
  { "Dome of the Sun", 0x411675BA, 800, 600, 3, 2016, 1736 }, -- before
  { "Dome of the Sun", 0x411675B9, 800, 600, 3, 2000, 1736 }, -- besieged
  { "Filgog\195\162n", 0x410EA78E, 1600, 1200, 3, 2000, 72 },
  { "Forges of Cirion", 0x41167853, 800, 600, 3, 2000, 1872 },
  { "Forlong's Hall", 0x4115F9C8, 800, 600, 3, 1216, 464 },
  { "Frodo's Bower", 0x411BA17A, 4800, 4800, 3, 2016, 1488 },
  { "Gladion's Home", 0x41155150, 800, 600, 3, 2016, 2032 },
  { "Great Hall of Garth Dn", 0x4116D888, 800, 600, 3, 1232, 768 },
  { "Great Hall of Tumladen", 0x41160177, 800, 600, 3, 1160, 480 },
  { "Great Hall of the Prince", 0x411552B0, 2400, 1800, 3, 2032, 1968 },
  { "Grot of Many Faces", 0x411BA17B, 1600, 1200, 3, 2016, 1504 },
  { "Hall of Crithost", 0x41165730, 800, 600, 3, 1304, 704 },
  { "Hall of Lady Vanyalos", 0x4115F9C9, 800, 600, 3, 1232, 512 },
  { "Hall of Ost Anglebed", 0x41159202, 1600, 1200, 3, 2032, 1920 },
  { "Hall of the Gentle Hand", 0x4115F9C7, 1600, 1200, 3, 1208, 512 },
  { "High Stables of Minas Tirith", 0x41167862, 800, 600, 3, 2016, 1592 },
  { "Homestead Provisions", 0x411A393C, 800, 600, 3, 840, 312 },
  { "House of Coins", 0x411552AF, 1600, 1200, 3, 2032, 1952 },
  { "Houses of Healing", 0x411676ED, 800, 600, 3, 2000, 1784 }, -- before
  { "Houses of Healing", 0x4115FA2A, 800, 600, 3, 2016, 1920 },
  { "Houses of Lore", 0x4116787C, 1600, 1200, 3, 2016, 1576 },
  { "H\195\186rin's Hall", 0x4115ED3E, 800, 600, 3, 2000, 1984 },
  { "Keep of the Swan-knights", 0x41155297, 1600, 1200, 3, 2032, 1984 },
  { "Lhingroth", 0x411544E3, 800, 600, 3, 2032, 1720 },
  { "Library of Saphadzr", 0x41154F52, 800, 600, 3, 2032, 1784 },
  { "Lighthouse of Aerthir", 0x411591FF, 1600, 1200, 3, 2032, 1936 },
  { "Lord Duinhir's Home", 0x41154E09, 800, 600, 3, 2032, 1752 },
  { "Lothgobel Home", 0x41155152, 800, 600, 3, 2016, 1968 },
  { "Lothgobel Home", 0x41155157, 800, 600, 3, 2016, 1936 },
  { "Lothgobel Home", 0x4115515B, 800, 600, 3, 2016, 1952 },
  { "Lothgobel Tavern", 0x41155153, 800, 600, 3, 2016, 1984 },
  { "Malthellam's Home", 0x41154E01, 800, 600, 3, 2032, 1768 },
  { "Mason of Dol Amroth", 0x4115529B, 800, 600, 3, 2032, 2016 },
  { "Merethrond", 0x41168FAC, 800, 600, 3, 2016, 1544 },
  { "Middle Stores", 0x411677D3, 800, 600, 3, 2000, 1888 },
  { "Nardol Mine", 0x4116D887, 3200, 2400, 3, 1160, 728 },
  { "Northern Lower Stores", 0x41167635, 800, 600, 3, 2000, 1768 },
  { "Old Guesthouse", 0x41167782, 800, 600, 3, 2016, 1904 },
  { "Orc Hideout", 0x4115ED40, 800, 600, 3, 2000, 1968 },
  { "Osgiliath Culverts", 0x4115F566, 800, 600, 3, 2000, 1936 },
  { "Ost Rimmon Stores", 0x4116D886, 800, 600, 3, 1088, 760 },
  { "Palace of Eldacar", 0x411601A6, 800, 600, 3, 2032, 1536 },
  { "Premium House", 0x411A4B90, 800, 600, 3, 1880, 1840 },
  { "Premium Kinship House", 0x411A4B91, 1600, 1200, 3, 1880, 1792 },
  { "Prison", 0x4115515C, 800, 600, 3, 2000, 2032 },
  { "Prison", 0x41159205, 800, 600, 3, 2032, 1904 },
  { "Southern Great Guesthouse", 0x4116787A, 2400, 1800, 3, 2016, 1560 },
  { "Southern Lower Stores", 0x411677D4, 800, 600, 3, 2000, 1904 },
  { "Spider Cave", 0x41159218, 800, 600, 3, 2032, 1608 },
  { "Sunken Labyrinth", 0x4115F4D7, 1600, 1200, 3, 2016, 1784 },
  { "Tavern", 0x4115921A, 800, 600, 3, 2032, 1624 },
  { "Tham Nadhron", 0x4116DA7E, 800, 600, 3, 1072, 824 },
  { "The Blue Theatre", 0x41168FAE, 800, 600, 3, 2032, 1504 },
  { "The Breach of Terror", 0x41170249, 3200, 2400, 3, 968, 1488 },
  { "The Crossing-hall", 0x41159219, 800, 600, 3, 2032, 1640 },
  { "The Dome of Stars", 0x411601A9, 1600, 1200, 3, 2032, 1552 },
  { "The Haven", 0x41167811, 800, 600, 3, 2032, 1888 },
  { "The High Archives", 0x4115FA2C, 1600, 1200, 3, 2032, 1568 },
  { "The House of Craft", 0x41167FCF, 800, 600, 3, 2032, 1872 },
  { "The Merry Swan", 0x41164BD3, 800, 600, 3, 2000, 1920 },
  { "The M\195\187mak and Keep", 0x41167866, 1600, 1200, 3, 2016, 1656 },
  { "The Old Archives", 0x41167865, 1600, 1200, 3, 2016, 1640 },
  { "The Splintered Shield", 0x41168FAB, 800, 600, 3, 2016, 1520 },
  { "The Thirsty Seer", 0x41168FAF, 800, 600, 3, 2032, 1520 },
  { "The Wheel and Cask", 0x41167810, 800, 600, 3, 2016, 1888 },
  { "Tingobel Mine", 0x41154505, 800, 600, 3, 2032, 1736 },
  { "Tower of Cirith Ungol", 0x41167864, 800, 600, 3, 2016, 1624 },
  { "Tower of Ecthelion", 0x4116786A, 1600, 1200, 3, 2016, 1720 }, -- before
  { "Tower of Ecthelion", 0x41167869, 1600, 1200, 3, 2016, 1704 },
  { "Training Ground", 0x41165BB4, 800, 600, 3, 2016, 1768 },
  { "Upper Stores", 0x41167634, 800, 600, 3, 2000, 1752 },
  { "Vault", 0x4115514F, 800, 600, 3, 2016, 2016 },
  { "Wine Cellar", 0x41159213, 800, 600, 3, 2032, 1672 },

  -- Region 4: Mordor / Post-Pelennor
  { "Adab Dolen", 0x411A45ED, 800, 600, 4, 2016, 1472 },
  { "Anglach", 0x411BABDA, 1600, 1200, 4, 2016, 1968 },
  { "Cirith Ungol", 0x411BA92E, 1600, 2400, 4, 2016, 1984 },
  { "City Stables of Minas Tirith", 0x41193306, 800, 600, 4, 2016, 1608 },
  { "Clothiers' Fellow-hall", 0x4119330A, 1600, 1200, 4, 2016, 1872 },
  { "Court of Seregost", 0x411BCC30, 1600, 1200, 4, 2016, 1888 }, -- main
  { "Court of Seregost", 0x411BCFD3, 1600, 1200, 4, 2016, 1888 }, -- end
  { "C\195\173rgalar", 0x411A45EB, 800, 600, 4, 2016, 1440 },
  { "Dome of the Sun", 0x41193308, 800, 600, 4, 2016, 1736 },
  { "Dungeons of Barad-d\195\187r", 0x411BAF90, 1600, 1200, 4, 2016, 1216 },
  { "Durthand", 0x411AF39F, 800, 600, 4, 2016, 2000 },
  { "Durthang", 0x411AF37E, 1600, 1200, 4, 2016, 2016 },
  { "Hall of the King", 0x411A75AD, 1600, 1200, 4, 2032, 1936 },
  { "High Stables of Minas Tirith", 0x41193305, 800, 600, 4, 2016, 1592 },
  { "House of Remedies", 0x41193301, 1600, 1200, 4, 2000, 1784 },
  { "House of Rest", 0x411703B7, 800, 600, 4, 2032, 2016 },
  { "Houses of Healing", 0x411A4A9F, 800, 600, 4, 2032, 1984 },
  { "Houses of Lore", 0x41193304, 1600, 1200, 4, 2016, 1576 },
  { "Lair of the Gloom-lord", 0x411BAF82, 800, 600, 4, 2016, 1200 },
  { "Merethrond", 0x41193302, 1600, 1200, 4, 2016, 1544 },
  { "Naerband", 0x411BD2B2, 2400, 1800, 4, 2032, 1640 }, -- private
  { "Naerband", 0x411BA624, 2400, 1800, 4, 2016, 1328 }, -- public
  { "Narchost", 0x411A44D3, 800, 600, 4, 2016, 2032 },
  { "Old Guest House", 0x4119330B, 1600, 1200, 4, 2016, 1904 },
  { "Orc-hold Caverns", 0x411BA988, 800, 600, 4, 2016, 1936 },
  { "Osgiliath Culverts", 0x411A4AA6, 1600, 1200, 4, 2032, 2000 },
  { "Palace of Eldacar", 0x411A4AA4, 800, 600, 4, 2032, 1968 },
  { "Pits of Seregost", 0x411BAF8F, 800, 600, 4, 2016, 1232 },
  { "Skoironk", 0x411A52F7, 800, 600, 4, 2016, 1424 },
  { "Southern Great Guesthouse", 0x41193303, 1600, 1200, 4, 2016, 1560 },
  { "Tham Falthad", 0x411A45EF, 800, 600, 4, 2016, 1456 },
  { "Tham Periain", 0x411A75AF, 2400, 1800, 4, 2032, 1920 },
  { "The Dome of Stars", 0x411A4AA0, 800, 600, 4, 2032, 1952 },
  { "The Haven", 0x4119330E, 800, 600, 4, 2032, 1888 },
  { "The High Hall", 0x411703B8, 800, 600, 4, 2032, 2032 },
  { "The House of Craft", 0x4119330D, 1600, 1200, 4, 2032, 1872 },
  { "The Old Archives", 0x41193307, 800, 600, 4, 2016, 1640 },
  { "The Thirsty Seer", 0x4119330C, 1600, 1200, 4, 2032, 1520 },
  { "Thurindath", 0x411A45F1, 800, 600, 4, 2016, 1488 },
  { "Torngroth", 0x411A45EE, 1600, 1200, 4, 2016, 1504 },
  { "Tower of Ecthelion", 0x4116786A, 1600, 1200, 4, 2016, 1720 }, -- after
  { "Towers of the Teeth", 0x411A52F9, 1600, 1200, 4, 2016, 1408 },
  { "Training Ground", 0x41193309, 800, 600, 4, 2016, 1768 },
  { "Upper Stores", 0x41193300, 800, 600, 4, 2000, 1752 }
}

function InteriorLocations.get(i)
  local v = InteriorLocations[i]
  if v == nil then
    return nil
  else
    return {
      name = v[1], did = v[2], w = v[3], h = v[4], r = v[5], lx = v[6], ly = v[7]
    }
  end
end

function InteriorLocations.iter()
  local i = 0
  local n = table.getn(InteriorLocations)
  return function()
    i = i + 1
    if i <= n then return InteriorLocations.get(i) end
  end
end

function InteriorLocations.find_did(did)
  local indices = {}
  for i, v in ipairs(InteriorLocations) do
    if v[2] == did then
      table.insert(indices, i)
    end
  end
  return indices
end

function InteriorLocations.find_name(name)
  local indices = {}
  for i, v in ipairs(InteriorLocations) do
    if v[1] == name then
      table.insert(indices, i)
    end
  end
  return indices
end
